close all; clear; clc;

%Example code that plots the structure displacement, ice force and relative
%ice-structure velocity of test ID 410, which represents an SDOF oscillator
%loaded by ice. The ice drift speed (following from the carriage speed)
%follows a linear downward-sloping velocity profile, going from 70 to
%0 mm/s in 400 s.

folder = '..\data\CSVTestFiles\';
fileName = 'Test0410_1706_7_SDOF_vNaN_2021-10-08-1617.csv';
filePath = [folder fileName];

data = readtable(filePath);

%%

carVel = data.CarVel_mm_s;   %Carriage velocity
strucWlPos = data.DisplY_mm; %Pile displacement (relative to carriage)
time = data.Time_s;
forceY = data.FPileY1_N;     %Ice force in y-direction, from strain gauge data
dispOffset = 50;             %Displacement offset in y-direction, see database

cutOffFrequency = 25;        %Cutoff frequency for filtering
dt = (time(10)-time(9));     
sampleFrequency = 1/dt;     

%Low-pass filter carriage velocity
carVelFilt = lowPassFilter(carVel,sampleFrequency,cutOffFrequency);

%Low-pass filter pile displacement
strucWlPosFilt = lowPassFilter(strucWlPos,sampleFrequency,cutOffFrequency);

%Differentiate pile displacement to get pile velocity (relative to
%carriage).
strucWlVel = gradient(strucWlPosFilt)/dt;

%Relative velocity between ice and structure:
relVel = carVelFilt+strucWlVel;

ax(1) = subplot(2,1,1);
yyaxis left
plot(time,-strucWlPos+dispOffset)
ylabel('Displacement [mm]')
xlim([993 1003])

yyaxis right
plot(time,-forceY)
ylabel('Force [N]')
grid on
xlim([993 1003])

% Settings figure
set(gca,'FontName','Times New Roman')
set(gcf,'color','w')

ax(2) = subplot(2,1,2);
plot(time,relVel)
ylabel('Relative velocity [mm/s]')
xlabel('Time [s]')
grid on
linkaxes(ax,'x')
xlim([993 1003])

% Settings figure
set(gca,'FontName','Times New Roman')
set(gcf,'color','w')




